@@ -8,6 +8,9 @@ import numpy as np
 import networkx as nx
 from hypernetx import HyperNetXError
 
+__all__ = ["Entity", "EntitySet"]
+
+
 class Entity(object):
     """
     Base class for objects used in building network-like objects including
@@ -22,6 +25,11 @@ class Entity(object):
         a list of entities with identifiers different than uid and/or
         hashables different than uid, see `Honor System`_
 
+    entity : Entity
+        an Entity object to be cloned into a new Entity with uid. If the uid is the same as
+        Entity.uid then the entities will not be distinguishable and error will be raised.
+        The `elements` in the signature will be added to the cloned entity.
+
     props : keyword arguments, optional, default: {}
         properties belonging to the entity added as key=value pairs.
         Both key and value must be hashable.
@@ -34,13 +42,13 @@ class Entity(object):
     The Entity class was created as a generic object providing structure for
     Hypergraph nodes and edges.
 
-    - An Entity is distinguished by its identifier (sortable,hashable) :code:`Entity.uid`
-    - An Entity is a container for other entities but may not contain itself, :code:`Entity.elements`
-    - An Entity has properties :code:`Entity.properties`
-    - An Entity has memberships to other entities, :code:`Entity.memberships`.
-    - An Entity has children, :code:`Entity.children`, which are the elements of its elements.
-    - :code:`Entity.children` are registered in the :code:`Entity.registry`.
-    - All descendents of Entity are registered in :code:`Entity.fullregistry()`.
+    - An Entity is distinguished by its identifier (sortable,hashable) :func:`Entity.uid`
+    - An Entity is a container for other entities but may not contain itself, :func:`Entity.elements`
+    - An Entity has properties :func:`Entity.properties`
+    - An Entity has memberships to other entities, :func:`Entity.memberships`.
+    - An Entity has children, :func:`Entity.children`, which are the elements of its elements.
+    - :func:`Entity.children` are registered in the :func:`Entity.registry`.
+    - All descendents of Entity are registered in :func:`Entity.fullregistry()`.
 
     .. _Honor System:
 
@@ -81,21 +89,35 @@ class Entity(object):
     EntitySet
 
     """
-    def __init__(self, uid, elements=[], **props):
+
+    def __init__(self, uid, elements=[], entity=None, **props):
         super().__init__()
+
         self._uid = uid
-        self._elements = dict()
-        self._memberships = dict()
-        self._registry = dict()
+
+        if entity is not None:
+            if isinstance(entity, Entity):
+                if uid == entity.uid:
+                    raise HyperNetXError(
+                        "The new entity will be indistinguishable from the original with the same uid. Use a differen uid."
+                    )
+                self._elements = entity.elements
+                self._memberships = entity.memberships
+                self.__dict__.update(entity.properties)
+        else:
+            self._elements = dict()
+            self._memberships = dict()
+            self._registry = dict()
+
         self.__dict__.update(props)
         self._registry = self.registry
 
-        if isinstance(elements,dict):
-            for k,v in elements.items():
-                if isinstance(v,Entity):
+        if isinstance(elements, dict):
+            for k, v in elements.items():
+                if isinstance(v, Entity):
                     self.add_element(v)
                 else:
-                    self.add_element(Entity(k,v))
+                    self.add_element(Entity(k, v))
         elif elements is not None:
             self.add(*elements)
 
@@ -103,10 +125,10 @@ class Entity(object):
     def properties(self):
         """Dictionary of properties of entity"""
         temp = self.__dict__.copy()
-        del temp['_elements']
-        del temp['_memberships']
-        del temp['_registry']
-        del temp['_uid']
+        del temp["_elements"]
+        del temp["_memberships"]
+        del temp["_registry"]
+        del temp["_uid"]
         return temp
 
     @property
@@ -127,11 +149,15 @@ class Entity(object):
         Dictionary of elements to which entity belongs.
 
         This assignment is done on construction and controlled by
-        :code:`Entity.add_element()` and :code:`Entity.remove_element()` methods.
+        :func:`Entity.add_element()`
+        and :func:`Entity.remove_element()` methods.
         """
 
-        return {k : self._memberships[k] for k in self._memberships
-            if not isinstance(self._memberships[k], EntitySet) }
+        return {
+            k: self._memberships[k]
+            for k in self._memberships
+            if not isinstance(self._memberships[k], EntitySet)
+        }
 
     @property
     def children(self):
@@ -140,6 +166,7 @@ class Entity(object):
 
         To return set of ids for deeper level use:
         :code:`Entity.levelset(level).keys()`
+        see: :func:`Entity.levelset`
         """
         return set(self.levelset(2).keys())
 
@@ -149,7 +176,7 @@ class Entity(object):
         Dictionary of uid:Entity pairs for children entity.
 
         To return a dictionary of all entities at all depths
-        :code:`Entity.complete_registry()`
+        :func:`Entity.complete_registry()`
         """
         return self.levelset(2)
 
@@ -160,7 +187,6 @@ class Entity(object):
         """
         return frozenset(self._elements.keys())
 
-
     @property
     def incidence_dict(self):
         """
@@ -189,8 +215,7 @@ class Entity(object):
         else:
             return False
 
-
-    def __eq__(self,other):
+    def __eq__(self, other):
         """
         Defines equality for Entities based on equivalence of their __dict__ objects.
 
@@ -202,25 +227,32 @@ class Entity(object):
         May cause a recursion error if depth is too great.
         """
         seen = set()
-        ## Define a compare method to call recursively on each level of self and other
-        def _comp(a,b,seen):
-            ## Compare top level properties: same class? same ids? same children? same parents? same attributes?
-            if (a.__class__ != b.__class__) or (a.uid != b.uid) or (a.uidset != b.uidset) or (a.properties != b.properties) or (a.memberships != b.memberships):
+        # Define a compare method to call recursively on each level of self and other
+
+        def _comp(a, b, seen):
+            # Compare top level properties: same class? same ids? same children? same parents? same attributes?
+            if (
+                (a.__class__ != b.__class__)
+                or (a.uid != b.uid)
+                or (a.uidset != b.uidset)
+                or (a.properties != b.properties)
+                or (a.memberships != b.memberships)
+            ):
                 return False
-            ## If all agree then look at the next level down since a and b share uidsets.
-            for uid,elt in a.elements.items():
+            # If all agree then look at the next level down since a and b share uidsets.
+            for uid, elt in a.elements.items():
                 if isinstance(elt, Entity):
                     if uid in seen:
                         continue
                     seen.add(uid)
                     if not _comp(elt, b[uid], seen):
                         return False
-                ## if not an Entity then elt is hashable so we usual equality
+                # if not an Entity then elt is hashable so we usual equality
                 elif elt != b[uid]:
                     return False
             return True
-        return _comp(self,other,seen)
 
+        return _comp(self, other, seen)
 
     def __len__(self):
         """Returns the number of elements in entity"""
@@ -228,12 +260,12 @@ class Entity(object):
 
     def __str__(self):
         """Return the entity uid."""
-        return f'{self.uid}'
+        return f"{self.uid}"
 
     def __repr__(self):
         """Returns a string resembling the constructor for entity without any
         children"""
-        return f'Entity({self._uid},{list(self.uidset)},{self.properties})'
+        return f"Entity({self._uid},{list(self.uidset)},{self.properties})"
 
     def __contains__(self, item):
         """
@@ -259,7 +291,7 @@ class Entity(object):
 
     def __getitem__(self, item):
         """
-        Returns Entity element by uid. Use :code:`E[uid]`.
+        Returns Entity element by uid. Use :func:`E[uid]`.
 
         Parameters
         ----------
@@ -271,8 +303,8 @@ class Entity(object):
 
         If item not in entity, returns None.
         """
-        if isinstance(item,Entity):
-            return self._elements.get(item.uid,'')
+        if isinstance(item, Entity):
+            return self._elements.get(item.uid, "")
         else:
             return self._elements.get(item)
 
@@ -285,7 +317,7 @@ class Entity(object):
         for e in self.elements.values():
             yield e
 
-    def __setattr__(self,k,v):
+    def __setattr__(self, k, v):
         """Sets entity property.
 
         Parameters
@@ -299,18 +331,17 @@ class Entity(object):
         None
 
         """
-        if k == 'uid':
+        if k == "uid":
             raise HyperNetXError(
-                'Cannot reassign uid to Entity once it'
-                ' has been created. Create a clone instead.'
-             )
-        elif k == 'elements':
-            raise HyperNetXError('To add elements to Entity use self.add().')
-        elif k == 'memberships':
+                "Cannot reassign uid to Entity once it"
+                " has been created. Create a clone instead."
+            )
+        elif k == "elements":
+            raise HyperNetXError("To add elements to Entity use self.add().")
+        elif k == "memberships":
             raise HyperNetXError(
-                'Can\'t choose your own memberships, '
-                'they are like parents!'
-                )
+                "Can't choose your own memberships, " "they are like parents!"
+            )
         else:
             self.__dict__[k] = v
 
@@ -328,7 +359,7 @@ class Entity(object):
         Dictionary extending entset
         """
         temp = dict()
-        for uid,item in entset.items():
+        for uid, item in entset.items():
             temp.update(item.elements)
         return temp
 
@@ -348,20 +379,22 @@ class Entity(object):
         -------
         level : int
 
+        Note
+        ----
         Item must be the uid of an entity listed
-        in :code:`fullregistry()`
+        in :func:`fullregistry()`
         """
         d = 1
         currentlevel = self.levelset(1)
-        while d <= max_depth+1:
+        while d <= max_depth + 1:
             if item in currentlevel:
                 return d
             else:
-                d +=1
+                d += 1
                 currentlevel = self._depth_finder(currentlevel)
         return None
 
-    def levelset(self,k=1):
+    def levelset(self, k=1):
         """
         A dictionary of level k of self.
 
@@ -373,16 +406,18 @@ class Entity(object):
         -------
         levelset : dict
 
+        Note
+        ----
         An Entity contains other entities, hence the relationships between entities
         and their elements may be represented in a directed graph with entity as root.
         The levelsets are sets of entities which make up the elements appearing at
         a certain level.
         """
-        if k<=0:
+        if k <= 0:
             return None
         currentlevel = self.elements
         if k > 1:
-            for idx in range(k-1):
+            for idx in range(k - 1):
                 currentlevel = self._depth_finder(currentlevel)
         return currentlevel
 
@@ -410,11 +445,11 @@ class Entity(object):
             return 0
         else:
             depth = 1
-        while depth < max_depth+1:
+        while depth < max_depth + 1:
             currentlevel = self._depth_finder(currentlevel)
             if not currentlevel:
                 return depth
-            depth +=1
+            depth += 1
         return np.inf
 
     def fullregistry(self, lastlevel=10, firstlevel=1):
@@ -435,7 +470,7 @@ class Entity(object):
         """
         currentlevel = self.levelset(firstlevel)
         accumulater = dict(currentlevel)
-        for idx in range(firstlevel,lastlevel):
+        for idx in range(firstlevel, lastlevel):
             currentlevel = self._depth_finder(currentlevel)
             accumulater.update(currentlevel)
         return accumulater
@@ -454,17 +489,16 @@ class Entity(object):
         return results
 
     @staticmethod
-    def _complete_registry(entity,results):
+    def _complete_registry(entity, results):
         """
         Helper method for complete_registry
         """
         for uid, e in entity.elements.items():
             if uid not in results:
                 results[uid] = e
-                Entity._complete_registry(e,results)
+                Entity._complete_registry(e, results)
 
-
-    def nested_incidence_dict(self,level=10):
+    def nested_incidence_dict(self, level=10):
         """
         Returns a nested dictionary with keys up to level
 
@@ -479,7 +513,7 @@ class Entity(object):
 
         """
         if level > 1:
-            return {ent.uid : ent.nested_incidence_dict(level-1) for ent in self()}
+            return {ent.uid: ent.nested_incidence_dict(level - 1) for ent in self()}
         else:
             return self.incidence_dict
 
@@ -489,7 +523,7 @@ class Entity(object):
         """
         return len(self)
 
-    def clone(self,newuid):
+    def clone(self, newuid):
         """
         Returns shallow copy of entity with newuid. Entity's elements will
         belong to two distinct Entities.
@@ -504,9 +538,9 @@ class Entity(object):
         clone : Entity
 
         """
-        return Entity(newuid, elements = self.elements.values(), **self.properties)
+        return Entity(newuid, entity=self)
 
-    def intersection(self,other):
+    def intersection(self, other):
         """
         A dictionary of elements belonging to entity and other.
 
@@ -540,7 +574,7 @@ class Entity(object):
 
         """
         newelements = [self[e] for e in element_subset if e in self]
-        name = name or f'{self.uid}_r'
+        name = name or f"{self.uid}_r"
         return Entity(name, newelements, **self.properties)
 
     def add(self, *args):
@@ -555,6 +589,12 @@ class Entity(object):
         -------
         self : Entity
 
+        Note
+        ----
+        Adding an element to an object in a hypergraph will not add the
+        element to the hypergraph and will cause an error. Use :func:`Hypergraph.add_edge <classes.hypergraph.Hypergraph.add_edge>`
+        or :func:`Hypergraph.add_node_to_edge <classes.hypergraph.Hypergraph.add_node_to_edge>` instead.
+
         """
         for item in args:
             self.add_element(item)
@@ -563,7 +603,7 @@ class Entity(object):
 
     def add_elements_from(self, arg_set):
         """
-        Similar to :code:`add()` it allows for adding from an interable.
+        Similar to :func:`add()` it allows for adding from an interable.
 
         Parameters
         ----------
@@ -603,45 +643,44 @@ class Entity(object):
 
         """
         checkelts = self.complete_registry()
-        if isinstance(item,Entity):
-        ## if item is an Entity, descendents will be compared to avoid collisions
+        if isinstance(item, Entity):
+            # if item is an Entity, descendents will be compared to avoid collisions
             if item.uid == self.uid:
                 raise HyperNetXError(
-                    f'Error: Self reference in submitted elements.'
-                    f' Entity {self.uid} may not contain itself. '
-                    )
+                    f"Error: Self reference in submitted elements."
+                    f" Entity {self.uid} may not contain itself. "
+                )
             elif item in self:
-                ## item is already an element so only the properties will be updated
+                # item is already an element so only the properties will be updated
                 checkelts[item.uid].__dict__.update(item.properties)
             elif item.uid in checkelts:
-                ## if item belongs to an element or a descendent of an element
-                ## then the existing descendent becomes an element
-                ## and properties are updated.
-                self._elements[item.uid] = checkelts[item.uid]
+                # if item belongs to an element or a descendent of an element
+                # then the existing descendent becomes an element
+                # and properties are updated.
                 checkelts[item.uid]._memberships[self.uid] = self
                 checkelts[item.uid].__dict__.update(item.properties)
+                self._elements[item.uid] = checkelts[item.uid]
             else:
-                ## if item's uid doesn't appear in complete_registry
-                ## then it is added as something new
+                # if item's uid doesn't appear in complete_registry
+                # then it is added as something new
                 item._memberships[self.uid] = self
                 self._elements[item.uid] = item
         else:
-            ## item must be a hashable.
-            ## if it appears as a uid in checkelts then
-            ## the corresponding Entity will become an element of entity.
-            ## Otherwise, at most it will be added as an empty Entity.
+            # item must be a hashable.
+            # if it appears as a uid in checkelts then
+            # the corresponding Entity will become an element of entity.
+            # Otherwise, at most it will be added as an empty Entity.
             if self.uid == item:
                 raise HyperNetXError(
-                    f'Error: Self reference in submitted elements.'
-                    f' Entity {self.uid} may not contain itself.'
-                    )
+                    f"Error: Self reference in submitted elements."
+                    f" Entity {self.uid} may not contain itself."
+                )
             elif item not in self._elements:
                 if item in checkelts:
                     self._elements[item] = checkelts[item]
                     checkelts[item]._memberships[self.uid] = self
                 else:
-                    self._elements[item] = \
-                        Entity(item, _memberships={self.uid: self})
+                    self._elements[item] = Entity(item, _memberships={self.uid: self})
 
         return self
 
@@ -661,12 +700,12 @@ class Entity(object):
 
         """
         for item in args:
-            Entity.remove_element(self,item)
+            Entity.remove_element(self, item)
         return self
 
-    def remove_elements_from(self,arg_set):
+    def remove_elements_from(self, arg_set):
         """
-        Similar to :code:`remove()`. Removes elements in arg_set.
+        Similar to :func:`remove()`. Removes elements in arg_set.
 
         Parameters
         ----------
@@ -678,10 +717,10 @@ class Entity(object):
 
         """
         for item in arg_set:
-            Entity.remove_element(self,item)
+            Entity.remove_element(self, item)
         return self
 
-    def remove_element(self,item):
+    def remove_element(self, item):
         """
         Removes item from entity and reference to entity from
         item.memberships
@@ -696,7 +735,7 @@ class Entity(object):
 
 
         """
-        if isinstance(item,Entity):
+        if isinstance(item, Entity):
             del item._memberships[self.uid]
             del self._elements[item.uid]
         else:
@@ -706,7 +745,7 @@ class Entity(object):
         return self
 
     @staticmethod
-    def merge_entities(name,ent1,ent2):
+    def merge_entities(name, ent1, ent2):
         """
         Merge two entities making sure they do not conflict.
 
@@ -728,14 +767,13 @@ class Entity(object):
         a new entity : Entity
 
         """
-        newent =  ent1.clone(name)
+        newent = ent1.clone(name)
         newent.add_elements_from(ent2.elements.values())
-        for k,v in ent2.properties.items():
-            newent.__setattr__(k,v)
+        for k, v in ent2.properties.items():
+            newent.__setattr__(k, v)
         return newent
 
 
-
 class EntitySet(Entity):
     """
     .. _entityset:
@@ -780,20 +818,22 @@ class EntitySet(Entity):
     """
 
     def __init__(self, uid, elements=[], **props):
-        super().__init__(uid, elements,  **props)
+        super().__init__(uid, elements, **props)
         if not self.is_bipartite:
-            raise HyperNetXError('Entity does not satisfy the Bipartite Condition, elements and children are not disjoint.')
+            raise HyperNetXError(
+                "Entity does not satisfy the Bipartite Condition, elements and children are not disjoint."
+            )
 
     def __str__(self):
         """Return the entityset uid."""
-        return f'{self.uid}'
+        return f"{self.uid}"
 
     def __repr__(self):
         """Returns a string resembling the constructor for entityset without any
         children"""
-        return f'EntitySet({self._uid},{list(self.uidset)},{self.properties})'
+        return f"EntitySet({self._uid},{list(self.uidset)},{self.properties})"
 
-    def add(self,*args):
+    def add(self, *args):
         """
         Adds args to entityset's elements, checking to make sure no self references are
         made to element ids.
@@ -811,19 +851,25 @@ class EntitySet(Entity):
         for item in args:
             if isinstance(item, Entity):
                 if item.uid in self.children:
-                    raise HyperNetXError(f'Error: Fails the Bipartite Condition for EntitySet. {item.uid} references a child of an existing Entity in the EntitySet.')
+                    raise HyperNetXError(
+                        f"Error: Fails the Bipartite Condition for EntitySet. {item.uid} references a child of an existing Entity in the EntitySet."
+                    )
                 elif not self.uidset.isdisjoint(item.uidset):
-                    raise HyperNetXError(f'Error: Fails the bipartite condition for EntitySet.')
+                    raise HyperNetXError(
+                        f"Error: Fails the bipartite condition for EntitySet."
+                    )
                 else:
-                    Entity.add_element(self,item)
+                    Entity.add_element(self, item)
             else:
                 if not item in self.children:
-                    Entity.add_element(self,item)
+                    Entity.add_element(self, item)
                 else:
-                    raise HyperNetXError(f'Error: {item} references a child of an existing Entity in the EntitySet.')
+                    raise HyperNetXError(
+                        f"Error: {item} references a child of an existing Entity in the EntitySet."
+                    )
         return self
 
-    def clone(self,newuid):
+    def clone(self, newuid):
         """
         Returns shallow copy of entityset with newuid. Entityset's
         elements will belong to two distinct entitysets.
@@ -839,27 +885,25 @@ class EntitySet(Entity):
         clone : EntitySet
 
         """
-        return EntitySet(newuid, elements = self.elements.values(), **self.properties)
+        return EntitySet(newuid, elements=self.elements.values(), **self.properties)
 
-
-    def collapse_identical_elements(self,newuid,use_reps=False,return_counts=False):
+    def collapse_identical_elements(self, newuid, return_equivalence_classes=False):
         """
-        Returns a deduped copy of the entityset, using equivalence classes as element keys.
+        Returns a deduped copy of the entityset, using representatives of equivalence classes as element keys.
+        Two elements of an EntitySet are collapsed if they share the same children.
 
         Parameters
         ----------
         newuid : hashable
 
-        use_reps : boolean, optional, default: False
-            Choose a single element from the collapsed elements as a representative
-
-        return_counts : boolean, optional, default: False
-            If use_reps is True the new elements are keyed the size of the equivalence class
-            otherwise they are keyed by a frozen set of equivalence classes
+        return_equivalence_classes : boolean, default=False
+            If True, return a dictionary of equivalence classes keyed by new edge names
 
         Returns
         -------
-        new entityset : EntitySet
+         : EntitySet
+        eq_classes : dict
+            if return_equivalence_classes = True
 
         Notes
         -----
@@ -876,27 +920,24 @@ class EntitySet(Entity):
             >>> E = EntitySet('E',elements=[Entity('E1', ['a','b']),Entity('E2',['a','b'])])
             >>> E.incidence_dict
             {'E1': {'a', 'b'}, 'E2': {'a', 'b'}}
-            >>> E.collapse_identical_elements('_').incidence_dict
-            {frozenset({'E1', 'E2'}): {'a', 'b'}}
-            >>> E.collapse_identical_elements('_',use_reps=True).incidence_dict
+            >>> E.collapse_identical_elements('_',).incidence_dict
             {'E2': {'a', 'b'}}
 
         """
 
-        temp = defaultdict(set)
+        shared_children = defaultdict(set)
         for e in self.__call__():
-            temp[frozenset(e.uidset)].add(e.uid)
-        if use_reps:
-            if return_counts:
-                ### labels equivalence class as (rep,count) tuple
-                new_entity_dict = {(next(iter(v)),len(v)):set(k) for k,v in temp.items()}
-            else:
-                ### labels equivalence class as rep;
-                new_entity_dict = {next(iter(v)):set(k) for k,v in temp.items()}
+            shared_children[frozenset(e.uidset)].add(e.uid)
+        new_entity_dict = {
+            f"{next(iter(v))}:{len(v)}": set(k) for k, v in shared_children.items()
+        }
+        if return_equivalence_classes:
+            eq_classes = {
+                f"{next(iter(v))}:{len(v)}": v for k, v in shared_children.items()
+            }
+            return EntitySet(newuid, new_entity_dict), dict(eq_classes)
         else:
-            new_entity_dict = {frozenset(v):set(k) for k,v in temp.items()}
-        return EntitySet(newuid,new_entity_dict)
-
+            return EntitySet(newuid, new_entity_dict)
 
     def incidence_matrix(self, sparse=True, index=False):
         """
@@ -938,17 +979,17 @@ class EntitySet(Entity):
         nchildren = len(self.children)
         nuidset = len(self.uidset)
 
-        ndict = dict(zip(self.children,range(nchildren)))
-        edict = dict(zip(self.uidset,range(nuidset)))
+        ndict = dict(zip(self.children, range(nchildren)))
+        edict = dict(zip(self.uidset, range(nuidset)))
 
-        if len(ndict) is not 0:
+        if len(ndict) != 0:
 
             if index:
-                rowdict = {v:k for k,v in ndict.items()}
-                coldict = {v:k for k,v in edict.items()}
+                rowdict = {v: k for k, v in ndict.items()}
+                coldict = {v: k for k, v in edict.items()}
 
             if sparse:
-                ### Create csr sparse matrix
+                # Create csr sparse matrix
                 rows = list()
                 cols = list()
                 data = list()
@@ -957,13 +998,13 @@ class EntitySet(Entity):
                         data.append(1)
                         rows.append(ndict[n])
                         cols.append(edict[e])
-                MP = csr_matrix((data,(rows,cols)))
+                MP = csr_matrix((data, (rows, cols)))
             else:
-                #### Create an np.matrix
-                MP = np.zeros((nchildren,nuidset),dtype=int)
+                # Create an np.matrix
+                MP = np.zeros((nchildren, nuidset), dtype=int)
                 for e in self:
                     for n in self[e].elements:
-                         MP[ndict[n],edict[e]]=1
+                        MP[ndict[n], edict[e]] = 1
             if index:
                 return MP, rowdict, coldict
             else:
@@ -974,7 +1015,7 @@ class EntitySet(Entity):
             else:
                 return np.zeros(1)
 
-    def restrict_to(self,element_subset,name=None):
+    def restrict_to(self, element_subset, name=None):
         """
         Shallow copy of entityset removing elements not in element_subset.
 
@@ -997,30 +1038,5 @@ class EntitySet(Entity):
 
         """
         newelements = [self[e] for e in element_subset if e in self]
-        name = name or f'{self.uid}_r'
+        name = name or f"{self.uid}_r"
         return EntitySet(name, newelements, **self.properties)
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
